#
# spec file for package python-CXX
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
%bcond_with     test
Name:           python-CXX
Version:        7.0.3
Release:        lp151.2.1
Summary:        Write Python extensions in C++
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://CXX.sourceforge.net/
Source0:        pycxx-%{version}.tar.gz
Source99:       python-CXX-rpmlintrc
Patch0:         python-CXX-6.2.3-change-include-paths.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%ifpython2
Obsoletes:      %{oldpython}-cxx < %{version}
Provides:       %{oldpython}-cxx = %{version}
%endif
%ifpython3
Obsoletes:      python3-cxx < %{version}
Provides:       python3-cxx = %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
PyCXX is a set of classes to help create extensions of Python in the C
language. The first part encapsulates the Python C API taking care of
exceptions and ref counting. The second part supports the building of Python
extension modules in C++.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
%ifpython2
Obsoletes:      %{oldpython}-cxx-devel < %{version}
Provides:       %{oldpython}-cxx-devel = %{version}
%endif
%ifpython3
Obsoletes:      python3-cxx-devel < %{version}
Provides:       python3-cxx-devel = %{version}
%endif

%description devel
Header files and documentation for %{name} development.

%prep
%setup -q -n pycxx-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
CURPY=`echo "%{$python_version}" | head -c 1`
INCDIR=%{$python_sysconfig_path include}
mkdir -p %{buildroot}/%{_datadir}/python%{$python_bin_suffix}/CXX/Python${CURPY}/
mkdir -p %{buildroot}/${INCDIR}/CXX/Python${CURPY}/
install -m 644 Src/*.* %{buildroot}/%{_datadir}/python%{$python_bin_suffix}/CXX/
install -m 644 CXX/*.* %{buildroot}/${INCDIR}/CXX/
install -m 644 Src/Python${CURPY}/*.* %{buildroot}/%{_datadir}/python%{$python_bin_suffix}/CXX/Python${CURPY}/
install -m 644 CXX/Python${CURPY}/*.* %{buildroot}/${INCDIR}/CXX/Python${CURPY}/
%fdupes  %{buildroot}/%{_datadir}/python%{$python_bin_suffix}
%fdupes  %{buildroot}/${INCDIR}/
}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root)
%doc README.html COPYRIGHT
%{python_sitelib}/CXX/
%{python_sitelib}/CXX-%{version}-py*.egg-info

%files %{python_files devel}
%defattr(-,root,root)
%python2_only %doc Doc/Python2/
%python2_only %doc Doc/Python3/
%python3_only %doc Demo/Python2/
%python3_only %doc Demo/Python3/
%dir %{_datadir}/python%{python_bin_suffix}
%dir %{_includedir}/python%{python_bin_suffix}*
%{_datadir}/python%{python_bin_suffix}/CXX/
%{_includedir}/python%{python_bin_suffix}*/CXX/

%changelog
* Tue Sep 12 2017 toddrme2178@gmail.com
- Fix provides/obsoletes
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to Version 7.0.3
  * Update Py::Long to support long long consitently between Python2 and Python3.
- Update to Version 7.0.2
  * Add Py::Char ord() method to return the long value of a character.
  * Fix String::size() that could return twice the actual length. This affected as_ucs4string() which would return a string with its second half as uninitialised memory.
  * Fix setup.py for the Demo code to build all the required C++ code.
- Update to Version 7.0.1
  * Add support for Full Unicode range on Windows.
  * Add sym link for README.txt to allow testing of index.html.
- Update to Version 7.0.0
  * Warning: This version fixes a number of problems that require source incompatible changes.
    However by defining PYCXX_6_2_COMPATIBILITY the V6.2.x API is restored. This is not recommended for new code.
  * The first version of python3 that is supported is 3.3.
  * New source file needs to built: Src/cxx_exceptions.cxx. This file implements the new exception handling features.
  * Fix the type used for lengths and sequence indexes to use Py_ssize_t. This will require sources changes for users of PyCXX.
  * Implement smart handling of Exceptions between C++ and Python. You can now catch exceptions in C++ by type that are raised in C++ or Python.
  * All builtin exceptions are support and are user defined exceptions.
  * The base exception type is now BaseException not Exception. To upgrade source code replace all use of Exception with BaseException.
  * The documentation has been updated to describe the new exception features.
  * The supportSequence, supportMapping, supportNumber etc functions now take a bit mask that defines which specific callbacks are handled.
- Update to Version 6.2.8
  * Fix crash when a member function is called via callMemberFunction() and that function raises an expection.
  * Found in comment on StackOverFlow. Fix memory size allocated for new objects. It used the wrong size calculation, but was big enough to avoid problems.
- Update to Version 6.2.7
  * Fix missing ptr__Unicode_Type.
  * Fixes from learn0more@gmail.com make python2 also remember the m_module and add accessor functions.
  * Fix for indirection issues from Vivian De Smedt.
  * Update to work with latest Microsoft Visual C++ for python 2.7. All test run in Win32 and Win64.
  * PyCXX.html documention has been updated, especially with 2TO3 information.
  * Use delete[] for objects allocated with new[].
- Update to Version 6.2.6
  * Fix build issue with GCC 4.2.1 on FreeBSD and Mac OS X (stop python defining isspace as a macro).
  * Remove support for python 3.1 (API's are unstable).
  * Add Python 3.3 support.
  * Patch from Michael Droettboom to fix compilation issues.
  * Patch from Michael Droettboom to add buffer interface for python3.
- Remove unneeded patch `python-CXX-6.2.5-fix-version.patch`
* Fri Dec  6 2013 toddrme2178@gmail.com
- Update to Version 6.2.5
  * Fix build issue with GCC 4.2.1 on FreeBSD and Mac OS X (stop python defining isspace as a macro).
  * Remove support for python 3.1 (API's are unstable).
  * Add Python 3.3 support.
  * Patch from Michael Droettboom to fix compilation issues.
  * Patch from Michael Droettboom to add buffer interface for python3.
- Remove upstreamed python-CXX-6.2.4-fix-indentation.patch
- Add python-CXX-6.2.5-fix-version.patch
  This will need to be fixed for any release where the version number is wrong
* Mon May 21 2012 toddrme2178@gmail.com
- Update to Version 6.2.4 (3-March-2012)
  * Fix problem compiling against clang compiler used with Mac OS X
    10.7
  * Fix segv when using getting the type() of extension objects
  * Support PEP 3149 * Support Python 3.2
  * For python 3.1 and onwards use the Capsule API - thanks to
    Michael Droettboom
  * Fixed memory leak - thanks to Vivian De Smedt
  * Improve setup_makefile.py to use distutils to find paths
- Rename to python-CXX to match python package naming policy
- Add python 3 package
- Clean up spec file formatting
* Fri Dec  9 2011 saschpe@suse.de
- License is BSD-3-Clause, not GPL
- Fix build for SLE-11
* Sun May  8 2011 andrea@links2linux.de
- New package
